@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 93 $
+# Revision: $Rev: 97 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -62,7 +62,7 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("lmc.py - LMC Movie Catalogue  $Rev: 93 $ (c) by Uwe Mayer")
+log.info("lmc.py - LMC Movie Catalogue  $Rev: 97 $ (c) by Uwe Mayer")
 
 # load settings
 settings = Settings.Settings()
@@ -295,12 +295,13 @@ class LMCMain(LMCWidgetBase):
         self.setCaption(filenameCaption(self.__file.name))
 
         # instanciate and new, empty center widget
-        self.setCentralWidget( RecordList(self) )
+        self.setCentralWidget( RecordList(dirname(filename), self) )
         self.centralWidget().show()
         # connect slots
         self.__enableSaveCloseActions()
 
 
+
     def fileOpen(self):
         """handles the open-existing-file process"""
         # query save when records dirty
